@@ -5,8 +5,6 @@
 
 from __future__ import annotations
 
-import os
-
 import pytest
 
 import vector
@@ -19,12 +17,6 @@ pytest.importorskip("vector.backends._numba_object")
 pytestmark = [pytest.mark.numba, pytest.mark.awkward]
 
 
-# awkward._v2 has not yet registered Numba dispatch mechanisms
-# see https://github.com/scikit-hep/awkward/discussions/1639
-# TODO: ensure this passes once awkward v2 is out
-@pytest.mark.xfail(
-    strict=True if os.environ.get("VECTOR_USE_AWKWARDV2") is not None else False
-)
 def test():
     @numba.njit
     def extract(x):
