@@ -14,10 +14,10 @@ import vector.backends.object
 
 def test_planar_object():
     v1 = vector.backends.object.VectorObject2D(
-        vector.backends.object.AzimuthalObjectXY(0.1, 0.2)
+        azimuthal=vector.backends.object.AzimuthalObjectXY(0.1, 0.2)
     )
     v2 = vector.backends.object.VectorObject2D(
-        vector.backends.object.AzimuthalObjectXY(0.3, 0.4)
+        azimuthal=vector.backends.object.AzimuthalObjectXY(0.3, 0.4)
     )
     assert v1.dot(v2) == pytest.approx(0.11)
 
